@@ -20,6 +20,8 @@
 #' that only a small proportion of mediators exhibit large effects
 #' ("active" mediators). \code{bama} uses a Metropolis-Hastings within Gibbs
 #' MCMC to generate posterior samples from the model.
+#' 
+#' @details NOTE: GMM not currently supported. Instead, use method = 'PTG'.
 #'
 #' @param Y Length \code{n} numeric outcome vector
 #' @param A Length \code{n} numeric exposure vector
@@ -32,7 +34,7 @@
 #' \itemize{
 #' \item{"BSLMM"}{ - mixture of two normal components; Song et al. 2019}
 #' \item{"PTG"}{ - product threshold Gaussian prior; Song et al. 2020}
-#' \item{"GMM"}{ - four-component Gaussian mixture prior; Song et al. 2020}
+#' \item{"GMM"}{ - NOTE: GMM not currently supported. Instead, use method = 'PTG'. four-component Gaussian mixture prior; Song et al. 2020}
 #' }
 #' @param inits list of initial values for the Gibbs sampler. Options are
 #' \itemize{
@@ -72,7 +74,7 @@
 #' \item{kma}{ - inverse gamma shape prior for tau.sq.a}
 #' \item{lma}{ - inverse gamma scale prior for tau.sq.a}
 #' }
-#' If \code{method = "GMM"}
+#' If \code{method = "GMM". NOTE: GMM not currently supported. Instead, use method = 'PTG'.}
 #' \itemize{
 #' \item{phi0}{ - prior beta.m variance}
 #' \item{phi1}{ - prior alpha.a variance}
@@ -129,6 +131,7 @@
 #' \item{call}{The R call that generated the output.}
 #' }
 #' 
+#' NOTE: GMM not currently supported. Instead, use method = 'PTG'
 #' If method = "GMM", then \code{bama} returns a object of type "bama" with:
 #' \describe{
 #' \item{beta.m}{\code{ndraws x p} matrix containing outcome model mediator
@@ -189,7 +192,7 @@
 #' alpha.a <- rep(0, 100)
 #'
 #' out <- bama(Y = Y, A = A, M = M, C1 = C1, C2 = C2, method = "BSLMM", seed = 1234,
-#'             burnin = 1000, ndraws = 1100, weights = NULL, inits = NULL, 
+#'             burnin = 100, ndraws = 110, weights = NULL, inits = NULL, 
 #'             control = list(k = 2, lm0 = 1e-04, lm1 = 1, l = 1))
 #'
 #' # The package includes a function to summarise output from 'bama'
@@ -199,7 +202,7 @@
 #' 
 #' # Product Threshold Gaussian 
 #' ptgmod = bama(Y = Y, A = A, M = M, C1 = C1, C2 = C2, method = "PTG", seed = 1234,
-#'               burnin = 1000, ndraws = 1100, weights = NULL, inits = NULL, 
+#'               burnin = 100, ndraws = 110, weights = NULL, inits = NULL, 
 #'               control = list(lambda0 = 0.04, lambda1 = 0.2, lambda2 = 0.2))
 #' 
 #' mean(ptgmod$beta.a)
@@ -208,19 +211,19 @@
 #' apply(ptgmod$betam_member, 2, mean)
 #' apply(ptgmod$alphaa_member, 2, mean)
 #' 
-#' # Gaussian Mixture Model
-#' gmmmod = bama(Y = Y, A = A, M = M, C1 = C1, C2 = C2, method = "GMM", seed = 1234,
-#'               burnin = 1000, ndraws = 1100, weights = NULL, inits = NULL, 
-#'               control = list(phi0 = 0.01, phi1 = 0.01))
-#' 
-#' mean(gmmmod$beta.a)
-#' apply(gmmmod$beta.m, 2, mean)
-#' apply(gmmmod$alpha.a, 2, mean)
-#' 
-#' mean(gmmmod$sigma.sq.a)
-#' mean(gmmmod$sigma.sq.e)
-#' mean(gmmmod$sigma.sq.g)
-#' 
+# # Gaussian Mixture Model
+# gmmmod = bama(Y = Y, A = A, M = M, C1 = C1, C2 = C2, method = "GMM", seed = 1234,
+#               burnin = 100, ndraws = 110, weights = NULL, inits = NULL, 
+#               control = list(phi0 = 0.01, phi1 = 0.01))
+# 
+# mean(gmmmod$beta.a)
+# apply(gmmmod$beta.m, 2, mean)
+# apply(gmmmod$alpha.a, 2, mean)
+# 
+# mean(gmmmod$sigma.sq.a)
+# mean(gmmmod$sigma.sq.e)
+# mean(gmmmod$sigma.sq.g)
+# 
 #' }
 #' 
 #' @references
@@ -453,6 +456,8 @@ bama <- function(Y, A, M, C1, C2, method, burnin, ndraws, weights = NULL, inits
         colnames(bama.out$alpha.a) <- colnames(M)
         
     } else if (method == "GMM") {
+      
+      stop("GMM is not currently supported. Instead, use method = 'PTG'.")
         
         if (!("phi0" %in% names(control)))
             control$phi0 = 0.01
@@ -490,36 +495,36 @@ bama <- function(Y, A, M, C1, C2, method, burnin, ndraws, weights = NULL, inits
         samples_sigmasqe = matrix(rep(0, (ndraws - burnin) * 1), nrow = (ndraws - burnin))
         samples_sigmasqg = matrix(rep(0, (ndraws - burnin) * 1), nrow = (ndraws - burnin))
 
-        gmm(Y = Y, 
-            A = A, 
-            M = M, 
-            C1 = C1,
-            C2 = C2,
-            ndraws = ndraws, 
-            burnin = burnin, 
-            seed = seed,
-            phi0 = control$phi0,
-            phi1 = control$phi1,
-            a0 = control$a0,
-            a1 = control$a1,
-            a2 = control$a2,
-            a3 = control$a3,
-            h1 = control$h1,
-            l1 = control$l1,
-            h2 = control$h2,
-            l2 = control$l2,
-            ha = control$ha,
-            la = control$la,
-            samples_betam = samples_betam, 
-            samples_alphaa = samples_alphaa,
-            betam_member = betam_member,
-            alphaa_member = alphaa_member,
-            samples_betaa = samples_betaa,
-            samples_alphac = samples_alphac,
-            samples_betac = samples_betac,
-            samples_sigmasqa = samples_sigmasqa,
-            samples_sigmasqe = samples_sigmasqe,
-            samples_sigmasqg = samples_sigmasqg)
+        # gmm(Y = Y, 
+        #     A = A, 
+        #     M = M, 
+        #     C1 = C1,
+        #     C2 = C2,
+        #     ndraws = ndraws, 
+        #     burnin = burnin, 
+        #     seed = seed,
+        #     phi0 = control$phi0,
+        #     phi1 = control$phi1,
+        #     a0 = control$a0,
+        #     a1 = control$a1,
+        #     a2 = control$a2,
+        #     a3 = control$a3,
+        #     h1 = control$h1,
+        #     l1 = control$l1,
+        #     h2 = control$h2,
+        #     l2 = control$l2,
+        #     ha = control$ha,
+        #     la = control$la,
+        #     samples_betam = samples_betam, 
+        #     samples_alphaa = samples_alphaa,
+        #     betam_member = betam_member,
+        #     alphaa_member = alphaa_member,
+        #     samples_betaa = samples_betaa,
+        #     samples_alphac = samples_alphac,
+        #     samples_betac = samples_betac,
+        #     samples_sigmasqa = samples_sigmasqa,
+        #     samples_sigmasqe = samples_sigmasqe,
+        #     samples_sigmasqg = samples_sigmasqg)
         
         bama.out$beta.m = samples_betam
         bama.out$alpha.a = samples_alphaa
@@ -561,7 +566,7 @@ bama <- function(Y, A, M, C1, C2, method, burnin, ndraws, weights = NULL, inits
 #' @export
 summary.bama <- function(object, rank = F, ci = c(0.025, .975), ...)
 {
-    if (class(object) != "bama")
+    if (!identical(class(object), "bama"))
         stop("'object' is not an bama object.")
 
     if (!is.logical(rank) || length(rank) != 1)
